
Custom tasks
=================

The RGA application is the srsgui application running with the configuration in the .taskconfig file in
the srsinst.rga package.

Make a copy of rga.taskconfig
------------------------------

Choose task from system packages or from local directory
---------------------------------------------------------


